@@ -18,10 +18,11 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gi
+gi.require_version('GMenu', '3.0')
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk, GdkPixbuf, Gdk, GMenu
 import sys
-import cgi
+import html
 import os
 import gettext
 import shutil
@@ -204,7 +205,7 @@ class MainWindow(object):
 
     def loadMenu(self, iters, parent=None):
         for menu, show in self.editor.getMenus(parent):
-            name = cgi.escape(menu.get_name())
+            name = html.escape(menu.get_name(), quote=False)
 
             icon = util.getIcon(menu)
             iters[menu] = self.menu_store.append(iters[parent], (icon, name, menu))
@@ -223,7 +224,7 @@ class MainWindow(object):
             else:
                 assert False, 'should not be reached'
 
-            name = cgi.escape(name)
+            name = html.escape(name, quote=False)
 
             self.item_store.append((show, icon, name, item))
 
@@ -239,17 +240,17 @@ class MainWindow(object):
             menu_tree.get_selection().select_path((0,))
         else:
             parent = menus[iter][2]
-	file_name = util.getUniqueFileId('alacarte-made', '.directory')
+        file_name = util.getUniqueFileId('alacarte-made', '.directory')
         file_path = os.path.join(util.getUserDirectoryPath(), file_name)
 
         editor = DirectoryEditor(self.main_window, file_path)
         editor.file_name = file_name;
         editor.parent = parent.get_menu_id()
-        editor.connect ('response', self.on_directory_created)
+        editor.connect('response', self.on_directory_created)
         editor.run()
 
     def on_directory_created(self, editor, response):
-        if response == True:
+        if response:
             self.editor.insertExternalMenu(editor.file_name, editor.parent)
 
     def on_new_item_button_clicked(self, button):
@@ -267,11 +268,11 @@ class MainWindow(object):
         editor = LauncherEditor(self.main_window, file_path)
         editor.file_name = file_name;
         editor.parent = parent.get_menu_id()
-        editor.connect ('response', self.on_item_created)
+        editor.connect('response', self.on_item_created)
         editor.run()
 
     def on_item_created(self, editor, response):
-        if response == True:
+        if response:
             self.editor.insertExternalItem(editor.file_name, editor.parent)
 
     def on_new_separator_button_clicked(self, button):
